mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Tony Luck <tony.luck@intel.com>
To: Fenghua Yu <fenghuay@nvidia.com>,
	Reinette Chatre <reinette.chatre@intel.com>,
	Maciej Wieczor-Retman <maciej.wieczor-retman@intel.com>,
	Peter Newman <peternewman@google.com>,
	James Morse <james.morse@arm.com>,
	Babu Moger <babu.moger@amd.com>,
	Drew Fustini <dfustini@baylibre.com>,
	Dave Martin <Dave.Martin@arm.com>, Chen Yu <yu.c.chen@intel.com>,
	David E Box <david.e.box@intel.com>,
	x86@kernel.org
Cc: Christoph Hellwig <hch@infradead.org>,
	linux-kernel@vger.kernel.org, patches@lists.linux.dev,
	Tony Luck <tony.luck@intel.com>
Subject: [PATCH v12 21/25] x86/resctrl: Export interface to report telemetry unbind/remove
Date: Wed, 16 Sep 2026 16:13:16 -0700	[thread overview]
Message-ID: <20260916231320.14502-22-tony.luck@intel.com> (raw)
In-Reply-To: <20260916231320.14502-1-tony.luck@intel.com>

Linux allows devices to be unbound from drivers, even if the modules
cannot be unloaded because of reference counts.

For telemetry this results in teardown of the virtual address mappings
of the MMIO regions which hold the event counters. Subsequent access
to these counters will page fault.

Export intel_aet_invalidate() for the pmt_telemetry module to inform
resctrl when invalidation is about to happen.

Signed-off-by: Tony Luck <tony.luck@intel.com>
---
v12:
	Update comment on aet_register_lock
---
 include/linux/intel_vsec.h              |  2 ++
 arch/x86/kernel/cpu/resctrl/intel_aet.c | 28 ++++++++++++++++++++++++-
 2 files changed, 29 insertions(+), 1 deletion(-)

diff --git a/include/linux/intel_vsec.h b/include/linux/intel_vsec.h
index c04b1d0f3143..bcbf4937c71c 100644
--- a/include/linux/intel_vsec.h
+++ b/include/linux/intel_vsec.h
@@ -262,11 +262,13 @@ void intel_aet_register_enumeration(struct module *module,
 				    struct pmt_feature_group *(*get)(enum pmt_feature_id id),
 				    void (*put)(struct pmt_feature_group *p));
 void intel_aet_unregister_enumeration(void);
+void intel_aet_invalidate(u8 package_id);
 #else
 static inline void intel_aet_register_enumeration(struct module *module,
 						  struct pmt_feature_group *(*get)(enum pmt_feature_id id),
 						  void (*put)(struct pmt_feature_group *p)) { }
 static inline void intel_aet_unregister_enumeration(void) { }
+static inline void intel_aet_invalidate(u8 package_id) { }
 #endif /* CONFIG_X86_CPU_RESCTRL_INTEL_AET */
 
 #endif
diff --git a/arch/x86/kernel/cpu/resctrl/intel_aet.c b/arch/x86/kernel/cpu/resctrl/intel_aet.c
index 8aa2e18a6bbb..1fd25fd9cd96 100644
--- a/arch/x86/kernel/cpu/resctrl/intel_aet.c
+++ b/arch/x86/kernel/cpu/resctrl/intel_aet.c
@@ -298,7 +298,7 @@ static enum pmt_feature_id lookup_pfid(const char *pfname)
 /*
  * Protects pmt_module, get_feature, put_feature against races between module
  * load/unload of the pmt_telemetry module and mount/unmount of the resctrl
  * file system. Also protects pmt_in_use.
  */
 static DEFINE_MUTEX(aet_register_lock);
 
@@ -365,6 +365,30 @@ void intel_aet_unregister_enumeration(void)
 }
 EXPORT_SYMBOL_NS_GPL(intel_aet_unregister_enumeration, "INTEL_PMT");
 
+/*
+ * pmt_telemetry driver calls this for unbind/remove operations that
+ * will invalidate the virtual addresses of MMIO registers provided
+ * by intel_pmt_get_regions_by_feature().
+ */
+void intel_aet_invalidate(u8 package_id)
+{
+	struct event_group **peg;
+
+	guard(mutex)(&aet_register_lock);
+
+	for_each_event_group(peg) {
+		struct event_group *e = *peg;
+
+		if (!e->pfg)
+			continue;
+		for (int i = 0; i < e->pfg->count; i++) {
+			if (e->pfg->regions[i].plat_info.package_id == package_id)
+				e->pfg->regions[i].addr = NULL;
+		}
+	}
+}
+EXPORT_SYMBOL_NS_GPL(intel_aet_invalidate, "INTEL_PMT");
+
 bool intel_aet_pre_mount(void)
 {
 	guard(mutex)(&aet_register_lock);
@@ -428,6 +452,8 @@ int intel_aet_read_event(int domid, u32 rmid, void *arch_priv, u64 *val)
 	void *pevt0;
 	u32 idx;
 
+	guard(mutex)(&aet_register_lock);
+
 	pevt0 = pevt - pevt->idx;
 	e = container_of(pevt0, struct event_group, evts);
 	idx = rmid * e->num_events;
@@ -298,7 +298,7 @@ static enum pmt_feature_id lookup_pfid(const char *pfname)
  * Protects pmt_module, get_feature, put_feature against races between module
  * load/unload of the pmt_telemetry module and mount/unmount of the resctrl
- * file system. Also protects pmt_in_use.
+ * file system. Also protects pmt_in_use telemetry_region::addr.
  */
 static DEFINE_MUTEX(aet_register_lock);
-- 
2.55.0


  parent reply	other threads:[~2026-09-16 23:13 UTC|newest]

Thread overview: 28+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-09-16 23:12 [PATCH v12 00/25] Allow AET to use PMT as loadable module Tony Luck
2026-09-16 23:12 ` [PATCH v12 01/25] x86/cpufeatures: Add missing CQM feature dependency Tony Luck
2026-09-16 23:12 ` [PATCH v12 02/25] x86/resctrl: Check if monitoring features are supported Tony Luck
2026-09-16 23:12 ` [PATCH v12 03/25] x86/resctrl: Enumerate monitor features in rdt_get_l3_mon_config() Tony Luck
2026-09-16 23:12 ` [PATCH v12 04/25] x86/resctrl: Apply Intel MBM quirk from rdt_get_l3_mon_config() Tony Luck
2026-09-16 23:13 ` [PATCH v12 05/25] x86/resctrl: Delete resctrl_cpu_detect() Tony Luck
2026-09-16 23:13 ` [PATCH v12 06/25] arm,x86,fs/resctrl: Replace architecture resctrl_arch_{alloc,mon}_capable() Tony Luck
2026-09-16 23:13 ` [PATCH v12 07/25] x86/resctrl: Update special case for Intel Haswell enumeration Tony Luck
2026-09-16 23:13 ` [PATCH v12 08/25] x86/resctrl: Delete rdt_alloc_capable and rdt_mon_capable Tony Luck
2026-09-16 23:13 ` [PATCH v12 09/25] fs/resctrl: Remove redundant calls to resctrl_{alloc,mon}_capable() Tony Luck
2026-09-16 23:13 ` [PATCH v12 10/25] x86/resctrl: Honor rdt=perf option to force enable AET perf events Tony Luck
2026-09-16 23:13 ` [PATCH v12 11/25] fs/resctrl: Add interface to disable a monitor event Tony Luck
2026-09-16 23:13 ` [PATCH v12 12/25] arm,x86,fs/resctrl: Allocate maximum needed rmid_ptrs[] Tony Luck
2026-09-16 23:13 ` [PATCH v12 13/25] arm,x86,fs/resctrl: Allocate right size for L3 monitor arrays Tony Luck
2026-09-16 23:13 ` [PATCH v12 14/25] fs/resctrl: Rebuild free RMID list on each mount Tony Luck
2026-09-16 23:13 ` [PATCH v12 15/25] x86,fs/resctrl: Handle systems where AET is the only resource Tony Luck
2026-09-16 23:13 ` [PATCH v12 16/25] x86/resctrl: Add PMT registration API for AET enumeration callbacks Tony Luck
2026-09-16 23:13 ` [PATCH v12 17/25] platform/x86/intel/pmt: Register enumeration functions with resctrl Tony Luck
2026-09-16 23:13 ` [PATCH v12 18/25] x86/resctrl: Use registered function pointers for AET enumeration Tony Luck
2026-09-16 23:13 ` [PATCH v12 19/25] arm,x86,fs/resctrl: Enumerate AET on every resctrl mount Tony Luck
2026-09-16 23:13 ` [PATCH v12 20/25] x86/resctrl: Enforce system RMID limit on AET Tony Luck
2026-09-16 23:13 ` Tony Luck [this message]
2026-09-16 23:13 ` [PATCH v12 22/25] platform/x86/intel/pmt: Inform resctrl when MMIO maps are being removed Tony Luck
2026-09-16 23:13 ` [PATCH v12 23/25] x86/resctrl: Require 64-bit x86 for resctrl support Tony Luck
2026-09-16 23:13 ` [PATCH v12 24/25] x86/resctrl: Simplify Kconfig options for resctrl Tony Luck
2026-09-16 23:13 ` [PATCH v12 25/25] x86,fs/resctrl: Document telemetry mount timing caveat Tony Luck
2026-09-17 16:32 ` [PATCH v12 00/25] Allow AET to use PMT as loadable module Luck, Tony
2026-09-17 21:23   ` Luck, Tony

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260916231320.14502-22-tony.luck@intel.com \
    --to=tony.luck@intel.com \
    --cc=Dave.Martin@arm.com \
    --cc=babu.moger@amd.com \
    --cc=david.e.box@intel.com \
    --cc=dfustini@baylibre.com \
    --cc=fenghuay@nvidia.com \
    --cc=hch@infradead.org \
    --cc=james.morse@arm.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=maciej.wieczor-retman@intel.com \
    --cc=patches@lists.linux.dev \
    --cc=peternewman@google.com \
    --cc=reinette.chatre@intel.com \
    --cc=x86@kernel.org \
    --cc=yu.c.chen@intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®